'use strict'
const path = require("path");
const webpack = require('webpack');

const merge = require('webpack-merge');
const baseConfig = require("./base");

const htmlWebpackPlugin = require('html-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin');
const CopyWebpackPlugin = require('copy-webpack-plugin');

function resolve (dir) {
  return path.join(__dirname, '..', dir)
}

module.exports = merge(baseConfig,{
	devtool: '#source-map',
	plugins:[
		new webpack.DefinePlugin({
			'process.env': {
		        NODE_ENV: '"production"'
		    }
	    }),
		new htmlWebpackPlugin({
			filename:'index.html',
			template:'index.html',
			inject: true,
		    minify: {
		        removeComments: true,
		        collapseWhitespace: true,
		        removeAttributeQuotes: false
		    },
		    chunksSortMode: 'dependency'
		}),
		new CleanWebpackPlugin(
            [resolve('dist/*')],　 //匹配删除的文件
            {
                root: '/',       　　　　　　　　　　//根目录
                verbose:  true,        　　　　　　　　　　//开启在控制台输出信息
                dry:      false        　　　　　　　　　　//启用删除文件
            }
        ),
        new ExtractTextPlugin('style/[name]-[contenthash].css'),
        new OptimizeCSSPlugin({
	      	cssProcessorOptions: {
	        	safe: true
	      	}
	    }),
	    new CopyWebpackPlugin([
	    {
	        from: resolve('client/static'),
	        to: resolve('dist/static'),
	        ignore: ['.*']
	      }
	    ]),
	    new webpack.optimize.UglifyJsPlugin({
	        compress: {
	          warnings: false,

	          // Drop `console` statements
	          drop_console: true
	        },
	        sourceMap: true
	    }),
	    new webpack.HashedModuleIdsPlugin(),
	    new webpack.optimize.CommonsChunkPlugin({
	      name: 'vendor',
	      minChunks: function (module) {
	        return (
	          module.resource &&
	          /\.(js|css)$/.test(module.resource) &&
	          module.resource.indexOf(
	            path.join(__dirname, '../node_modules')
	          ) === 0
	        )
	      }
	    }),
	    new webpack.optimize.CommonsChunkPlugin({
	      name: 'manifest',
	      chunks: ['vendor']
	    })
	]
});
